==> cookcli-0.19.0.tar.gz: cookcli-0.19.0/tests/e2e/recipe-scaling.spec.ts <==
import { test, expect } from '@playwright/test';
import { TestHelpers, RecipePage } from '../fixtures/test-helpers';

test.describe.skip('Recipe Scaling', () => {  // Skip - requires recipe with scaling
  let helpers: TestHelpers;
  let recipePage: RecipePage;

  test.beforeEach(async ({ page }) => {
    helpers = new TestHelpers(page);
    recipePage = new RecipePage(page, helpers);
    await helpers.navigateTo('/');

    // Navigate to first actual recipe (not directory)
    const recipes = page.locator('a[href^="/recipe/"]');
    const count = await recipes.count();
    if (count > 0) {
      await recipes.first().click();
      await page.waitForLoadState('networkidle');
    }
  });

  test('should display scale input', async ({ page }) => {
    const scaleInput = page.locator('#scale');
    const isVisible = await scaleInput.count() > 0;

    if (isVisible) {
      await expect(scaleInput).toBeVisible();
      await expect(scaleInput).toHaveValue('1');
    } else {
      // No recipe loaded or no scaling available
      expect(page.url()).toMatch(/\/$|directory/);
    }
  });

  test('should scale recipe by changing input', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Get original ingredient values
      const ingredientsList = page.locator('ul').filter({ has: page.locator('.ingredient-badge') });
      const originalText = await ingredientsList.textContent();

      // Scale recipe to 2x
      await helpers.scaleRecipe(2);

      // Check URL updated with scale parameter
      expect(page.url()).toContain('scale=2');

      // Check that scale input shows new value
      await expect(scaleInput).toHaveValue('2');

      // Verify page reloaded with scaled values
      const scaledText = await ingredientsList.textContent();
      // Content should exist
      expect(scaledText).toBeTruthy();
    } else {
      expect(true).toBe(true);
    }
  });

  test('should scale recipe via URL parameter', async ({ page }) => {
    if (page.url().includes('/recipe/')) {
      // Navigate directly with scale parameter
      const currentUrl = page.url().split('?')[0];
      await page.goto(currentUrl + '?scale=3');
      await page.waitForLoadState('networkidle');

      // Check scale input reflects URL parameter
      const scaleInput = page.locator('#scale');
      if (await scaleInput.count() > 0) {
        await expect(scaleInput).toHaveValue('3');
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should handle decimal scaling', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale to 0.5 (half)
      await helpers.scaleRecipe(0.5);

      // Check URL and input
      expect(page.url()).toContain('scale=0.5');
      await expect(scaleInput).toHaveValue('0.5');

      // Scale to 1.5
      await helpers.scaleRecipe(1.5);
      expect(page.url()).toContain('scale=1.5');
      await expect(scaleInput).toHaveValue('1.5');
    } else {
      expect(true).toBe(true);
    }
  });

  test('should reset scaling to 1', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale up first
      await helpers.scaleRecipe(2);
      expect(page.url()).toContain('scale=2');

      // Reset to 1
      await helpers.scaleRecipe(1);

      // URL should either not have scale param or have scale=1
      const url = page.url();
      const hasScaleParam = url.includes('scale=');

      if (hasScaleParam) {
        expect(url).toContain('scale=1');
      }

      await expect(scaleInput).toHaveValue('1');
    } else {
      expect(true).toBe(true);
    }
  });

  test('should maintain scaling when adding to shopping list', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale recipe to 2x
      await helpers.scaleRecipe(2);

      // Add to shopping list
      const addButton = page.getByRole('button', { name: /Add to Shopping List/i });

      if (await addButton.count() > 0) {
        await addButton.click();
        await page.waitForTimeout(500);

        // Navigate to shopping list
        await helpers.goToShoppingList();

        // Verify scaled ingredients are in shopping list
        const shoppingListItems = await page.locator('li').count();
        expect(shoppingListItems).toBeGreaterThan(0);
      } else {
        expect(true).toBe(true);
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should show servings adjustment if available', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Check if servings information exists
      const servingsElement = page.locator('text=/serving|portion/i');

      if (await servingsElement.count() > 0) {
        const originalServings = await servingsElement.textContent();

        // Scale recipe
        await helpers.scaleRecipe(2);

        // Check if servings updated
        const scaledServings = await servingsElement.textContent();

        // Servings might be updated or might show "2x" indicator
        expect(scaledServings).toBeTruthy();
      } else {
        // No servings info
        expect(true).toBe(true);
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should validate scale input', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Input has min="0.5" max="200" attributes

      // Try value below min
      await scaleInput.fill('0.1');
      await scaleInput.dispatchEvent('change');
      await page.waitForTimeout(500);

      // Browser might allow but server should handle
      const value = await scaleInput.inputValue();
      expect(Number(value)).toBeGreaterThan(0);

      // Try valid value
      await scaleInput.fill('2');
      await scaleInput.dispatchEvent('change');
      await page.waitForTimeout(500);

      const validValue = await scaleInput.inputValue();
      expect(Number(validValue)).toBe(2);
    } else {
      expect(true).toBe(true);
    }
  });

  test('should preserve scaling on page refresh', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale recipe
      await helpers.scaleRecipe(2);
      const urlWithScale = page.url();

      // Refresh page
      await page.reload();
      await page.waitForLoadState('networkidle');

      // Check scaling is preserved
      expect(page.url()).toBe(urlWithScale);
      await expect(scaleInput).toHaveValue('2');
    } else {
      expect(true).toBe(true);
    }
  });
});

==> cookcli-0.22.0.tar.gz: cookcli-0.22.0/tests/e2e/recipe-scaling.spec.ts <==
import { test, expect } from '@playwright/test';
import { TestHelpers, RecipePage } from '../fixtures/test-helpers';

test.describe('Recipe Scaling', () => {
  let helpers: TestHelpers;
  let recipePage: RecipePage;

  test.beforeEach(async ({ page }) => {
    helpers = new TestHelpers(page);
    recipePage = new RecipePage(page, helpers);
    await helpers.navigateTo('/');

    // Navigate to first actual recipe (not directory or menu)
    const recipes = page.locator('a[href^="/recipe/"][href$=".cook"]');
    const count = await recipes.count();
    if (count > 0) {
      await recipes.first().click();
      await page.waitForLoadState('networkidle');
    }
  });

  test('should display scale input', async ({ page }) => {
    const scaleInput = page.locator('#scale');
    const isVisible = await scaleInput.count() > 0;

    if (isVisible) {
      await expect(scaleInput).toBeVisible();
      await expect(scaleInput).toHaveValue('1');
    } else {
      // No recipe loaded or no scaling available
      expect(page.url()).toMatch(/\/$|directory/);
    }
  });

  test('should scale recipe by changing input', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale recipe to 2x
      await helpers.scaleRecipe(2);

      // Check that scale input shows new value
      await expect(scaleInput).toHaveValue('2');

      // URL will update after navigation/reload, not immediately from input change
      if (page.url().includes('scale=')) {
        expect(page.url()).toContain('scale=2');
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should scale recipe via URL parameter', async ({ page }) => {
    if (page.url().includes('/recipe/')) {
      // Navigate directly with scale parameter
      const currentUrl = page.url().split('?')[0];
      await page.goto(currentUrl + '?scale=3');
      await page.waitForLoadState('networkidle');

      // Check scale input reflects URL parameter
      const scaleInput = page.locator('#scale');
      if (await scaleInput.count() > 0) {
        await expect(scaleInput).toHaveValue('3');
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should handle decimal scaling', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale to 0.5 (half)
      await helpers.scaleRecipe(0.5);
      await expect(scaleInput).toHaveValue('0.5');

      // Scale to 1.5
      await helpers.scaleRecipe(1.5);
      await expect(scaleInput).toHaveValue('1.5');
    } else {
      expect(true).toBe(true);
    }
  });

  test('should reset scaling to 1', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale up first
      await helpers.scaleRecipe(2);
      await expect(scaleInput).toHaveValue('2');

      // Reset to 1
      await helpers.scaleRecipe(1);
      await expect(scaleInput).toHaveValue('1');
    } else {
      expect(true).toBe(true);
    }
  });

  test('should maintain scaling when adding to shopping list', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Scale recipe to 2x
      await helpers.scaleRecipe(2);

      // Add to shopping list
      const addButton = page.getByRole('button', { name: /Add to Shopping List/i });

      if (await addButton.count() > 0) {
        await addButton.click();
        await page.waitForTimeout(500);

        // Navigate to shopping list
        await helpers.goToShoppingList();

        // Verify scaled ingredients are in shopping list
        const shoppingListItems = await page.locator('li').count();
        expect(shoppingListItems).toBeGreaterThan(0);
      } else {
        expect(true).toBe(true);
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should show servings adjustment if available', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Check if servings information exists
      const servingsElement = page.locator('text=/serving|portion/i');

      if (await servingsElement.count() > 0) {
        const originalServings = await servingsElement.textContent();

        // Scale recipe
        await helpers.scaleRecipe(2);

        // Check if servings updated
        const scaledServings = await servingsElement.textContent();

        // Servings might be updated or might show "2x" indicator
        expect(scaledServings).toBeTruthy();
      } else {
        // No servings info
        expect(true).toBe(true);
      }
    } else {
      expect(true).toBe(true);
    }
  });

  test('should validate scale input', async ({ page }) => {
    const scaleInput = page.locator('#scale');

    if (await scaleInput.count() > 0) {
      // Input has min="0.5" max="200" attributes

      // Try value below min
      await scaleInput.fill('0.1');
      await scaleInput.dispatchEvent('change');
      await page.waitForTimeout(500);

      // Browser might allow but server should handle
      const value = await scaleInput.inputValue();
      expect(Number(value)).toBeGreaterThan(0);

      // Try valid value
      await scaleInput.fill('2');
      await scaleInput.dispatchEvent('change');
      await page.waitForTimeout(500);

      const validValue = await scaleInput.inputValue();
      expect(Number(validValue)).toBe(2);
    } else {
      expect(true).toBe(true);
    }
  });

  test('should preserve scaling on page refresh', async ({ page }) => {
    // Navigate with scale parameter first
    if (page.url().includes('/recipe/')) {
      const currentUrl = page.url().split('?')[0];
      await page.goto(currentUrl + '?scale=2');
      await page.waitForLoadState('networkidle');

      const scaleInput = page.locator('#scale');
      if (await scaleInput.count() > 0) {
        await expect(scaleInput).toHaveValue('2');

        // Refresh page
        await page.reload();
        await page.waitForLoadState('networkidle');

        // Check scaling is preserved
        expect(page.url()).toContain('scale=2');
        await expect(scaleInput).toHaveValue('2');
      }
    } else {
      expect(true).toBe(true);
    }
  });
});
